==> vpn-portal-artwork-lc-3.0.0.tgz: vpn-user-portal/views/LC/vpnPortalHome.php <==
<?php declare(strict_types=1); ?>
<?php /** @var \Vpn\Portal\Tpl $this */ ?>
<?php /** @var int $maxActiveConfigurations */ ?>
<?php $this->layout('base', ['activeItem' => 'home', 'pageTitle' => $this->t('Home')]); ?>
<?php $this->start('content'); ?>
    <p class="lead"><?=$this->t('Welcome to Let\'s Connect!'); ?></p>

    <p>
        <?=$this->t('To use Let\'s Connect!, download the app for your device below!'); ?>
    </p>

    <ul class="apps">
        <li>
            <a target="_blank" class="Windows" href="https://app.letsconnect-vpn.org/windows/LetsConnectClient_latest.exe"><?=$this->t('Windows'); ?></a>
        </li>

        <li>
            <a target="_blank" class="macOS" href="https://apps.apple.com/app/lets-connect-vpn/id1486810037"><?=$this->t('macOS'); ?></a>
        </li>

        <li>
            <a target="_blank" class="Android" href="https://play.google.com/store/apps/details?id=org.letsconnect_vpn.app"><?=$this->t('Android'); ?></a>
        </li>

        <li>
            <a target="_blank" class="iOS" href="https://apps.apple.com/app/lets-connect-vpn/id1449261843"><?=$this->t('iOS'); ?></a>
        </li>

        <li>
            <a target="_blank" class="Linux" href="https://python-eduvpn-client.readthedocs.io/"><?=$this->t('Linux'); ?></a>
        </li>
    </ul>

    <p>
        <?= $this->t('On the "Account" page you can block access to the VPN in case you lose a device, or no longer use the VPN.'); ?>
    </p>

<?php if (0 !== $maxActiveConfigurations): ?>
    <p>
        <?= $this->t('If you do not want to, or cannot use the official Let\'s Connect! apps, you can also manually obtain a VPN configuration and import it in your existing VPN application.'); ?>
    </p>
    <details>
        <summary><?= $this->t('Manual Configuration'); ?></summary>
<?= $this->insert('manualConfiguration'); ?>
    </details>
<?php endif; ?>
<?php $this->stop('content'); ?>

==> vpn-portal-artwork-lc-3.0.1.tgz: vpn-user-portal/views/LC/vpnPortalHome.php <==
<?php declare(strict_types=1); ?>
<?php /** @var \Vpn\Portal\Tpl $this */ ?>
<?php /** @var int $maxActiveConfigurations */ ?>
<?php $this->layout('base', ['activeItem' => 'home', 'pageTitle' => $this->t('Home')]); ?>
<?php $this->start('content'); ?>
    <p class="lead"><?=$this->t('Welcome to Let\'s Connect!'); ?></p>

    <p>
        <?=$this->t('To use Let\'s Connect!, download the app for your device below!'); ?>
    </p>

    <ul class="apps">
        <li>
            <a target="_blank" class="Windows" href="https://app.letsconnect-vpn.org/windows/LetsConnectClient_latest.exe"><?=$this->t('Windows'); ?></a>
        </li>

        <li>
            <a target="_blank" class="macOS" href="https://apps.apple.com/app/lets-connect-vpn/id1486810037"><?=$this->t('macOS'); ?></a>
        </li>

        <li>
            <a target="_blank" class="Android" href="https://play.google.com/store/apps/details?id=org.letsconnect_vpn.app"><?=$this->t('Android'); ?></a>
        </li>

        <li>
            <a target="_blank" class="iOS" href="https://apps.apple.com/app/lets-connect-vpn/id1449261843"><?=$this->t('iOS'); ?></a>
        </li>

        <li>
            <a target="_blank" class="Linux" href="https://docs.eduvpn.org/client/linux/"><?=$this->t('Linux'); ?></a>
        </li>
    </ul>

    <p>
        <?= $this->t('On the "Account" page you can block access to the VPN in case you lose a device, or no longer use the VPN.'); ?>
    </p>

<?php if (0 !== $maxActiveConfigurations): ?>
    <p>
        <?= $this->t('If you do not want to, or cannot use the official Let\'s Connect! apps, you can also manually obtain a VPN configuration and import it in your existing VPN application.'); ?>
    </p>
    <details>
        <summary><?= $this->t('Manual Configuration'); ?></summary>
<?= $this->insert('manualConfiguration'); ?>
    </details>
<?php endif; ?>
<?php $this->stop('content'); ?>
